# GMA

## Original code

[https://github.com/zacjiang/GMA](https://github.com/zacjiang/GMA)

## Code license

See [LICENSE](LICENSE).

## Pretrained weights license

Not specified.

## Citation

```
@inproceedings{jiang2021learning,
  title={Learning to Estimate Hidden Motions with Global Motion Aggregation},
  author={Jiang, Shihao and Campbell, Dylan and Lu, Yao and Li, Hongdong and Hartley, Richard},
  booktitle={ICCV},
  year={2021}
}
```